@@ -1,27 +1,29 @@
-import gpiod
 import sys
 from datetime import timedelta
+import gpiod
 
 try:
     if len(sys.argv) > 3:
         BUTTON_CHIP = sys.argv[1]
         BUTTON_LINE_OFFSETS = []
         for i in range(len(sys.argv) - 3):
-            BUTTON_LINE_OFFSETS.append(int(sys.argv[i+2]))
+            BUTTON_LINE_OFFSETS.append(int(sys.argv[i + 2]))
 
         edge = sys.argv[len(sys.argv) - 1]
-        if edge[0] == 'r':
+        if edge[0] == "r":
             BUTTON_EDGE = gpiod.line_request.EVENT_RISING_EDGE
-        elif edge[0] == 'f':
+        elif edge[0] == "f":
             BUTTON_EDGE = gpiod.line_request.EVENT_FALLING_EDGE
         else:
             BUTTON_EDGE = gpiod.line_request.EVENT_BOTH_EDGES
     else:
         raise Exception()
 except:
-    print('''Usage:
+    print(
+        """Usage:
     python3 -m gpiod.test.bulk_button <chip> <line offset> [<line offset2> ...]
-        <[rising|falling|both]>''')
+        <[rising|falling|both]>"""
+    )
     sys.exit()
 
 chip = gpiod.chip(BUTTON_CHIP)
